@@ -1,8 +1,7 @@
 from os import error
 
-def serial():
+def introduction():
     import time
-
     print("Thanks for using pymewc to record any issue mail to gr8rithic@gmail.com")
     time.sleep(1)
     print('----------------------------------------------------------------------------------------------------')
@@ -23,7 +22,8 @@ def serial():
     print("Setting up the environment")
     time.sleep(3)
 
-
+def serial():
+    introduction()
     com_port = input("Enter the com-port(Com4 or /dev/ttyACM0 on Windows and Unix based respectively)")
     baud_rate = int(input("Enter the baud rate as specified in the .ino file"))
     import serial  
@@ -34,7 +34,6 @@ def serial():
 
     while(1):
         try:
-            
             x = (ser.readline().strip())            
             print("Check the usb port is mentioned correctly or usb is connected properly")
             y = (x.decode('utf-8'))       
@@ -44,5 +43,6 @@ def serial():
             continue                      
 
 def hello():
-    print("Hellow world")
+    introduction()
+    print("Hellow world, The package is properly installed version = 0.0.7")
 
